-module(tpTracerConsole).

-export([start_link/2]).
-export([
   init/1
   , loop/1
]).


-export([system_continue/3]).
-export([system_terminate/4]).
-export([system_code_change/4]).

start_link(_Nth, _TracerOpts) ->
   Pid = proc_lib:spawn_link(?MODULE, init, [self()]),
   {ok, Pid}.

init(Parent) ->
   process_flag(message_queue_data, off_heap),
   loop(Parent).

loop(Parent) ->
   receive
      {system, From, Request} ->
         sys:handle_system_msg(Request, From, Parent, ?MODULE, [], Parent);
      RMsg ->
         %% Convert the event's monotonic time to its system time.
         Msg = setelement(3, RMsg, erlang:time_offset(microsecond) + element(3, RMsg)),
         erlang:display(Msg),
         loop(Parent)
   end.

system_continue(_, _, Parent) ->
   loop(Parent).

-spec system_terminate(any(), _, _, _) -> no_return().
system_terminate(Reason, _, _, _) ->
   exit(Reason).

system_code_change(Misc, _, _, _) ->
   {ok, Misc}.
